#
# spec file for package fldigi
#
# Copyright (c) 2023-2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fldigi
Version:        4.2.06
Release:        lp156.93.3
Summary:        Digital modem program (hamradio)
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://sourceforge.net/projects/fldigi/
#Git-Clone:     https://git.code.sf.net/p/fldigi/fldigi
Source:         http://downloads.sourceforge.net/project/%{name}/%{name}/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  systemd-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(flxmlrpc)
BuildRequires:  pkgconfig(hamlib)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
Requires(post): update-desktop-files
Requires(postun):update-desktop-files
Recommends:     %{name}-lang

%description
Digital modem program.
Supports the following modes:
CW, Contestia, DominoEX, Hell, MFSK, MT63, Olivia, Psk, RTTY, Thor, Throb
WEFAX, WWV calibration, Frequency Analysis, Tune

%lang_package

%package -n flarq
Summary:        Transmitting and receiving frames of ARQ data (hamradio)
Group:          Productivity/Hamradio/Other
Requires(post): update-desktop-files
Requires(postun):update-desktop-files

%description -n flarq
Fast Light Automatic Repeat reQuest is a file transfer application that is based
on the ARQ specification developed by Paul Schmidt, K9PS.  It is capable of
transmitting and receiving frames of ARQ data via Fldigi. The interaction
between Flarq and Fldigi requires no operator intervention.

%prep
%setup -q

%build
export BUILD_DATE=`date -d@0`
export BUILD_USER=openSUSE
export BUILD_HOST=openSUSE
%configure
%make_build

%install
%make_install
%find_lang %{name}
%fdupes -s %{buildroot}/%{_mandir}

%suse_update_desktop_file -i fldigi
%suse_update_desktop_file -i flarq

%check
make %{?_smp_mflags} check

%if 0%{?suse_version} < 1325
%post
%desktop_database_post

%post -n flarq
%desktop_database_post

%postun
%desktop_database_postun

%postun -n flarq
%desktop_database_postun
%endif

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/fldigi
%{_datadir}/applications/fldigi.desktop
%{_datadir}/pixmaps/fldigi.xpm
%{_datadir}/fldigi/
%{_mandir}/man1/fldigi.1%{ext_man}

%files lang -f %{name}.lang

%files -n flarq
%{_bindir}/flarq
%{_datadir}/applications/flarq.desktop
%{_datadir}/pixmaps/flarq.xpm
%{_mandir}/man1/flarq.1%{ext_man}

%changelog
* Fri Oct 18 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 4.2.06:
  * MFSK for QRP Labs qmx/qmxp
    + remove silence period after preamble
    . qmx drops transmit signal after initial mfsk preamble
    . RsID signal should not be used with qmx series xcvr
  * ADIF correction
    + correct various FeldHell ADIF reports:
    . Feld Hell <MODE:4>HELL
    . Slow Hell <MODE:4>HELL
    . Feld Hell X5 <MODE:4>HELL
    . Feld Hell X9 <MODE:4>HELL
    . FSK Hell-245 <MODE:7>FSKH105
    . FSK Hell-105 <MODE:7>FSKH245
    . Hell 80 <MODE:6>HELL80
    In the current ADIF specification
    https://adif.org.uk/314/ADIF_314.htm#Mode_Enumeration
  - FSKH105 and FSKH245 do not exist as MODE in the ADIF specification
  - HELL80 is a SUBMODE rather than MODE, so should be exported =
    as <MODE:4>HELL <SUBMODE:6>HELL80
    . <MODE:4>HELL <SUBMODE:8>SLOWHELL
    . <MODE:4>HELL <SUBMODE:6>HELLX5
    . <MODE:4>HELL <SUBMODE:6>HELLX9
  * FSQ rx/tx freq
    + Remove variable frequency selection on configuration tab
  * color prefs
    + move color definitions from configuration to a separate
    prefs file to allow independent color renderings.
    + specify all colors as a triad: red, green, blue 0 to 255
  * Main dialog position
    + allow location on left-center-right monitors. n5
  * Micro modems
    + change name to avoid double word parsing issues with
    frequencies2.txt
  * colors and scheme
    + allow user to select default background and foreground
    colors
    . supplements command line usage
  * @QSY+ macro tag
    + QSY after TX to RX transition
  * autotools: update m4 macros
  * fw / ww
  * Wordsworth keying
    + Correct spacing algorithm using smaller intervals
    of silence to avoid audio stream buffer overflow
    + simultaneous farnsworth / wordsworth keying.
    if and only if: wordsworth < farnsworth < keying wpm
  * UDP/CLOUD log record
    + add write log record to UDP socket concurrent with other
    internal and external logbook recording. UDP record in
    ADIF format and contains the fields specified on the UDP
    field selection dialog.
    + Add field selection for cloud logbook export
    + UDP and CLOUD export records are terminated by the <EOR>
    tag.
    + Make field selection paradigm identical for udp and cloud
    exports.
    + ADIF specification compliance
    . change frequency field comma, ",", to period "."
  * FMT thread
    + insure that FMT thread is closed when modem is deleted
    . windows gags on multiple threads writing to same object
    + put a whole file lock on the csv file during entire time
    it is being written to by the FMT modem. Excel is an
    ultra greedy application that attempts to lock a file before
    any reads or writes and does so even to a file opened for
    write by another program. Bah Humbug!
* Wed May  1 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 4.2.05:
  * Documentation Update
    + Script command RSID BW_MIN.
    + Script command C-Media PTT.
    + Html generated page formatting issues related to escape
    sequence characters in source.
    + Document Source code formatting issues related to end of
    line/return characters   (blasted text editor differences).
  * RSID Scripting
    + Add RSID minimum bandwidth script command.
    + Add missing top level script list of commands.
    + Comment out machine specific generated script file commands.
    + Filter values to their modulus "step" values.
  * Main X-Y-W-H restore: allow negative X, Y value
  * pi-winkeyer: repair broken winkeyer serial i/o on Pi computers
  * Add code to force default language to be English
  * RSID Min Bandwidth
    + add user adjustable bandwidth for minimum RsID detection
    range.
    + display RsID detection zone on waterfall (dashed lines) when
    RsID is both ON and limited to a specific bandwidth range
  * OFDM documentation
    + Update, remove unsupported OFDM modes
  * remove all instances of ° from strings literals
  * DominoEX MFSK Thor s/n
    + s/n & fec reports are erroneous when macro used to fill
    in those values during subsequent transmit.
    . change to provide last Rx max s/n & min error report
    . values displayed in Status fields will time out and clear
    in 15 seconds.
  * gpio ptt: increase OS wait time before sending bit values
  * fsq mod: reinstate squelch countdown
  * Add CW send using Wordsworth timing
  * RsID
    + add LOG_INFO statement to notifier dialog call
  * Add user adjustable menu font and font size
  * Update po files
  * Scope colors
    + add user defined colors for all instances of scope view
    + update fl files generation to fluid 1.3.9
* Wed Jan 17 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 4.2.04:
  * PO files:
    + Add Catalan ca.po
    + Update Greek el.po
  * xmlrpc remote log: set xmlrpc execute timeout to 10.0 seconds
    for all fllog access
  * update font browser widget class to use std::list for
    enumerating fonts
  * gpio ptt: correct gpio export routine
  * MACRO tags: Add missing trailing '>' to macro tag string definitions
  * RsID Rx button color: remove from button initialization list
  * hamlib 4.6 bug fix: hamlib 4.6~git changes creates incompatible
    call with previous versions of the library
  * FMT zombie: fix potential thread zombie if FMT modem shut down
    during a log write
  * Squelch Macro tags
  * Add
    + <SQL:on|off|t> Digital Squelch on, off,toggle
    + <SQLCH:nnn> Digital Squelch level, 0..100
  * CLRLOG LOG LNW: Correct macro functions
  * metar report: add unprocessed ob: line as a report option
  * Log fields
    + add MY_STATE
    + trim leading/trailing blanks
    + add UK counties to counties list
    + changed short form to blank when NIL selected for state
    + store fldigi version number in SQSO.txt file
    + regenerate list from internal string if version number does
    not match with executing binary
* Sun Nov  5 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
-  update to 4.2.03:
  * Maintenance release
  * FSQ sounding CR/LF
    + add newline character at end of Sounding report
    + correct thread loop counter test
-  update to 4.2.02:
  * fsq coding error: correct coding error reported by Ken, AD5XJ
-  update to 4.2.01:
  * fsq sounder
    + change sounder squelch to only ch_sqlch_open state
    + recode sounder as a separate thread
  * FSK port: missing port assignment when NOT using shared port
  * Cloud log update: add color indicators to validate cloud log
    connection
  * frequencies2 list
    + add Save/Load to specific file
    + "Clear" button changed to three state function
    click - clear list with confirmation
    SHIFT-click - load from file
    CONTROL-click - save to file
    + last load/save filename saved between executions
  * fix gnu++ 11.17.xx warnings
  * flrig auto shutdown: move closure point to just before
    destroying the xmlrpc instance
  * Light Buttons: add missing buttons to configuration color
    control
  * OFDM_2000 OFDM_2000F:  stub out all references to these two
    modes
  * New XMLRPC Command: Add "modem.get_io_names" Transfers 8 bit
    safe modem list
  * Serial i/o: port serial i/o changes from flrig
  * Icons: set_msg_icon segmentation fault when parent widget is
    NULL
* Sun Sep  3 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to 4.2.00:
  * THOR
    + add THOR-56 modem
    + add THOR-32 and THOR-44 modems
    + update THOR documentation
  * TTY ptt dtr/rts:
    + configuration item not being set by combo selection
    + update to flrig code
  * Correct position/width/shape of waterfall cursor center tic
  * Revert "improved s/n and squelch processing" mod
* Wed Jul 19 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to 4.1.27:
  * restore missing <PAUSE> function
  * fix and simplify navtex timing recovery logic
  * add TEN_TEN field to log.adif file
  * add CTRL-P as pause/break equivalent keystroke
  * FSQ: improved s/n and squelch processing
    . faster acting squelch open/close
    . modified s/n evaluator
  * improved s/n and squelch processing
    + squelch opens and closes faster
    + better s/n estimator
  * EQSL submission: always submit last dated log entry independent
    of sort order
  * wfonly fix: segmentation fault during startup, NULL control
  * enable https queries in callook.info
  * Miscellaneous gcc cleanup
  * allow user to specify which avatar image to use for ifkp/thor
    transmission
    + recommend files be located in default <fldigi_files>/avatar/ folder
    + file format may be gif, jpeg or png
    + order of default file use:
    . <configured file name>.png [PNG, jpg, JPG, jpeg, JPEG, gif]
    . <operator call>.png
    . <station call>.png
    + trailing callsign modifiers will be removed from the file
    name i.e. AE5ZA/QRP is reduced to AE5ZA
    + different avatar can be used for IFKP and THOR
    + configuration items are clickable images on both IFKP and THOR
    configuration tabs.
    + image files no longer restricted to 59x74 format.
  * Set contest start nbr XMLRPC
    + add set contest start number xmlrpc method, update counter
    and current contest number
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1.26:
  * Audio Monitor
  * musl file conflict
  * Add documentation for Cloudlog part
  * Add button for testing the API key
  * cloud logging
  * window icon tranparency
  * fonts
  * FC LEAVE
* Sat Feb 25 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.25
- Update to version 4.1.24
  * CTY.dat: create separate configuration tab
  * transfer changes in flrig cwio speed to tx wpm vice rx wpm
  * update FreqControl for compatability with fltk-1.4
  * Improved reliability of freq control from fldigi when using
    N3FJP for rig control
  * Greek po file update: Haris Andrianos <sv1grb@...>
  * Polish po file update: Roman Bagiński <sp4jeu@...>
  * allow user selectable vumeter scale
    + original audio level scale
    + wsjtx emulation
  * add right click to FSQ QTC/QTH buttons to access edit controls
  * replicate the QTH control on the FSQ config panel
  * Rx audio gain parameter corrected
  * Tx audio fixed, fixed at last ring buffer too small for some
    modem types
  * expand mode state to index both by-mode and by-band
  * correct rtty squelch estimation for zero signal, zero noise
  * Add Audio Filter bandwidth lines to waterfall display
  * change CAT keying to allow up to 100 WPM on K4.
  * stub out audio alert and rx monitor functions if Portaudio
    library not present
  * Made Frequency Control behavior consistent across flapps
  * Fixed County combo box crash to desktop
  * Fixed 30 meter CW shortcut in frequencies2.txt
  * Fixed grid locator spec in pskreporter query
  * Fixed crash-to-desktop upon Activity (pskreporter) query.
* Thu Jun 30 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.23
  * Remove C17 deprecated use of "std::iterator"
  * Correct errors caused by commit 9c035e809b, original commit
    failed to correctly send flmsg autosend character stream
  * modify debugging statements in xmlrpc notch
  * audio alerts / monitor
    + change sound card defaults
  * nanoIO ptt
    + bug fix
  * cw browser
    + partial reversion of commit dbe3622cc4d01f7
    + bug fixes for multi signal cw decoder
    + correct marquee scrolling to use all of available space
  * Signal browser
    + correct marquee end of line detection
  * cw via flrig
    + remove dead code
  * update build scripts for recent development OS update
  * FSK via flrig / nanoIO
    + add automatic insertion of '[' and ']' start/stop characters
  * INSTALL update
    + update dependency list
* Sat May 14 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.22
  * add missing call to set_mode_afc in Save/Restore AFC by mode
- Update to version 4.1.21
  * IPC log report: change logging date report to date ON vice date OFF
  xmlrpc methods
  * add new methods all data in ADIF 3.1.2 compliant format:
    + logbook.last_record
    + logbook.all_records
  * add new methods as ADIF 3.1.2 compliant strings:
    + modem.get_mode
    + modem.get_submode
  * add new date-time methods
    . log.get_time_on
    . log.get_date_on
    . log.get_time_off
    . log.get_date_off
  * date-time correctly synchronized and in ZULU time
  CW h/w weight
  * provide control to control keying weight for DTR/RTS keying.
  build m4 script
  * correction to m4 build script for libmbedtls test
  TRX FFT
  * Add fft monitoring of transmitted signal
  flrig poll
  * provide user configurable poll interval
  CW/FSK
  * update flrig cw/rtty code
  * update rigcat FSK code
  - separate all bit timing from main thread
  - adjust sleep method for OS-X performance
  - adjust sleep method for Windows OS
  * add missing FSK commport control initialization
  * update cwio DTR/RTS rigcat keying
  - replace bit timing with high resolution interval timer
  - deprecate timing compensation
  - test satisfactory on Linux, 5 to 100 WPM
  log macro
  * fix parsing bug when a trailing <HS, <LOCK etc is in macro text
  psk reporter
  * update to report generation logic
  FFT Monitor update
  * Add complex signal processing to FFT usage
  CW multi-channel
  * changed cw viewer multi-decoder filtering to use independent
    fir bandpass filter centered on 50 Hz intervals
    . out-of-band reject 60 dB between adjacent channels
  * add right click clears channel to cw viewer
  FSK keying
  * add ability to key xcvr in FSK using either
    . a DTR or RTS serial signal line (default RTS).
    . serial port can be shared with rigio or a separate port
  * SPACE always sent as LETTERS character
  * 100%% functional on Linux including Pi3/4
  * 100%% functional on on macOS 11.6, 10.13.6, and 10.7.5
  * 100%% functional on Win-10
  * BUG - fixed excessive CPU usage while Tx without text (idle)
  * TIMING - tune timing loop for slow cpu's such as Pi3
  * update to accu_sleep
    . improved function performance
    . move accu_sleep to util.cxx
  * update to baudot generator
  * add flrig / FSK interface
  xmlrpc QSY
  * add enable/disable QSY xmlrpc command for server
  dxcluster
  * bug - do not change mode if comments do not contain
    a valid ADIF mode name
  * set correct mode based on dxline contents
  * qsy to rf/sweetspot for identified mode Mode Parameters
  * save squelch settings by mode and reapply when
    mode selected: squelch value, squelch button
    . setting saved in file squelch_by_mode.prefs located
    in the fldigi main files folder. prefs files are
    user editable text format which are read during
    program start up.
  * save and reapply AFC state by mode
  * save and reapply TX level attenuator by mode
  * initialize all values to current states on first
    execution, or when file mode_state.prefs is deleted.
  Documentation update
  * add/update documentation for Domino-EX Micro, OFDM modes,
    Thor Micro, Thor 25/50/100, 8 psk modes
  Polish translation update
  * update to pl.po provided by Roman Baginski, SP4JEU
  synop event reporting
  * changed default event reporting to VERBOSE to reduce event
    log noise for users not operating SYNOP
  using namespace std
  + remove all use of "using namespace std"
  + add explicit "std::" predecessor for every standard lib reference
* Sun Aug 15 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.20
  Add OFDM modes for NBEMS
  - OFDM-500F for HF SSB
  - OFDM-750F for HF SSB
  - OFDM-2000F for HF-SSB/FM
  - OFDM-2000 for HF-SSB/FM
  - OFDM-3500 for FM 9600-port
  - OFDM-2000F CPU-load fix
  * Added Vestigial-carrier based AFC to OFDM modes
  - Increases robustness and tolerance to drift
  * OFDM 2000F hold
  * commented out OFDM 2000 and 2000F modes for bugfixes
  * OFDM 500F, 750F, and 3500 are complete
  Cosmetic changes
  * Fix cosmetic issues reported by Bob, VK2YQA
  * Fix parse of macro <PUSH>
  Gleam scheme
  * add fltk 'gleam' UI scheme
  xmlrpc id
  * add client ID to client requests
  * add client ID to server parsing
  cw tracking
  * adjust tracking filter constants to improve power detection
  Navtex modem
  * make single bit flip correction guess a little smarter
  Smeter Pwr_meter
  * correction to xmlrpc procedure to get smeter and power out
    meter from flrig
  My Callsign
  * modify edit code to maintain cursor position
  Contest fields
  * Change to Rx text field parsing
  * Change to cut number parsing
  gpio ptt
  * fix for pi3/4 gpio h/w UDRC-II operation
* Fri Jul  2 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.19
  * maintenance release
  Vestigial AFC fixes
  * Fix OFDM and 8PSK AFC jumping randomly to noise-signals
  C-Media PTT support
  * add support for C-Media ptt signal, used by DAR-30 etal
  LNW macro tag
  * add missing add to log call
  Notes
  * add Notes as a retrieve field for last worked call lookup in
    logbook
  lower case tx
  * defeat lower case TX when text source is from arq or xmlrpc
    socket interface.
  Qso Party Cabrillo
  * add state & country selections
  mxe scripts update
  cwid
  * enable cwid for
    . T/R button reset to Rx
    . ^r in xmlrpc transmit text strings
    . ^r in macro text
    . ^r in transmit text
    NOTE: recommend disabling cwid for all ARQ type message
    transmissions; flarq / flmsg.
  Doxygen srcdoc fix
  * MBEDTLS breaks the cppcheck tool, bypass checking for now
  Dxcluster freq
  * change to accommodate either '.' or ',' as the integer
    fractional part of frequency in kHz.
  Documentation update
  * image and text associated with menu items
    . View/Rig/Log Controls
    . View/Waterfall
  Carat r/R
  * if modem is not IFKP, change to identical function for ^r and
    ^R transmit character sequence
  Compiler warnings
  * fix compiler warning on use of memset
    . rsid.cxx
    . ifkp.cxx
  flrig cwio
  * DTR/RTS CW keying using xmlrpc commands to flrig
  Set/Get Notch
  * Correct notch processing when used with flrig
  * RigCAT notch processing
    . Add wait 2 poll cycles between set and get notch
  FMT mod
  * limit estimation error to user defined value, reset tracking if
    error exceeds the set value
  * add +/- 5 and +/- 10 plot ranges
  Tx Monitor Level
  * Change control to dB scale to allow greater range of user control
  fh baud
  * modify fh parameter printout
  dxcluster
  * Immediate cmd
    . ! character as first in command definition will cause the command
    to be send immediate upon selection of that command button
  WF-only mode menu
  * add missing modes
  PSK-modes fix false triggers of DCD-OFF
  * Certian character combinations were triggering DCD-OFF
  * DCD-OFF code now searches over 6-bit window
  * Prevents rare data-loss bug mid-transmission
  fmt
  * add callback handlers to
    . btn_unk_enable
    . btn_ref_enable
    . btn_fmt_record
  * reset frequency whenever ref or unk button is pressed
  CW punctuation
  * Allow user to suppress decode/encode of specific punctuation
    characters
  * Allow user to select character to display noise decodes
    . default '*'
    . '_'
    . ' '
    . none
  WX
  * Correct <WX:xxx> weather macro text substitution
  Canada
  * Add missing provinces / regions
  PulseAudio Server String
  * always enable PA server string control to allow user to
    clear or modify entry
  * fix hanging up on server fault message dialog
    . caused by message dialog on being re-entrant
  Waterfall buttons
  * Set all buttons to visibile for new installation
  Audio Codec
  * fix for Portaudio h/w codec missing during fldigi startup
    . missing h/w could cause segmentation fault on some systems
    . added try{}catch{} to trx audio path
    . display error message
    . reset audio device to NULL codec
* Thu Feb  4 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.18
  WF fft controls
  * Restore averaging, fft pre filter, latency controls
  Debug text
  * add millisecond timing to debug time stamp
  flarq build
  * fix broken build for ./configure --disable-fldigi --enable-debug
  Exit processing
  * Set PTT off if user elects to close fldigi with PTT enabled.
  - works for both Files/Exit and the dreaded windows decoration
    bar 'X' button.
  Scheduled Macro
  * Add PTT OFF during scheduled count down
  * Add clock display on status bar during scheduled count down
  * remove end-of-line '\n' white space between macro tags, i.e.
    <!WPM:24>
    <LOCAL><!SKED:12:00>how now brown cow<RX>
    becomes
    ^!^!how now brown cow
    after parser substitutions
  * Add space ' ' to end of inserted file <FILE:...> if file does
    not contain either ' ' or '\n' as last character
  xmlrpc
  * flrig detection update
  flarq debug
  * fix to allow --enable-debug with flarq build
  Doc update
  * CW CAT keying, add IC705 to list of tested transceivers
* Wed Dec  9 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.17
  N3FJP support
  * remove sending OTHER8 category for all logs
  CW keying
  * added Elecraft KY cat command CW string keying
    . K3S tested
  * added Kenwood KY cat command CW string keying
    . TS-480 tested
  * added Icom cat command CW string keying
    . IC-7100, IC-705 tested
  * added Yaesu cat CW string keying
    . FT-991a tested
  * For use ONLY with
    . RigCAT transceiver control
    . flrig transceiver control
  - requires flrig 1.3.53 or greater
  Rx Monitor
  * fluid source cleanup
  * split UI source from confdialog.fl
  Contestia / Olivia
  * Added mode CONTESTIA 16/250 with RsID 275
  * Added macro code to allow any valid Contestia or
    Olivia BW/TONES combination to be set via macro tags:
    . <MODEM:CONTESTIA:BW:TONES>
    . <MODEM:OLIVIA:BW:TONES>
    . where BW in set {125, 250, 500, 1000, 2000}
    TONES in set {2, 4, 8, 16, 32, 64, 256}
  Greek translation
  * Update to Greek po file
* Wed Nov 18 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.16
  Cty.dat
  * Update distibution cty.dat data files
    dated 12 November 2020
  Greek translation
  * Update to Greek po files
  Globals
  * fix MODE_THOR_FIRST entry.
  * fix MODE_DOMINOEX_FIRST entry.
  fmt fixes
  * track colors not correctly shown on tracking indicators
  view_cw
  * change sample rate to be keyed to cw decoder samplerate
  Canadian Provinces
  * update user configuration panel
  FreeBSD/nullptr
  * nullptr is defined in _null.h
  Navtex
  * fix kml file clean up code
  benchmark
  * update to current gcc version
  Phase and FEC quality display
  * Add phase-accuracy display for PSK modes (non-PSK31)
  * Added better FEC confidence code to THOR
  Add new platform optimizations
  * added new --enable-optimizations options to ./configure
    RaspberryPi 1,2,3,4 [rpi1, rpi2, rpi3, rpi4]
    BeagleBone Black [bbb]
    Cyclone5 [cyclone5]
    Optimize for sse4 [sse4]
    Use AVX extensions [avx, avx2]
    i486, i686 [i486, i686]
    x86-64 [x86-64]
    ARM CPU-native [nativeARM]
  Updated Doxygen Sourcecode Docs
  * Now renders to SVG for graphics (doxygen 1.18)
  * Fixed scripts for Cppcheck 1.9 changes
  * Added auto-installer for packages on Debian-like systems
  * Improved main page: index.html
  fonts
  * fix slow start caused by font fixed/proportional enumeration
  * fixed evaluator moved to separate thread during first
    instantiation of Font_Browser class.  Actual time to enumerate
    2650 fonts on an i5 3.2 GHz system is approximately 25
    seconds. Background process does not effect UI, but selection
    of fixed fonts in font browser dialog may not show all of the
    fixed fonts until the evaluator thread exits.
  PSK Reporter query
  * request fails to pskreporter, caused by hard coded request to NWS
    pskreporter site very slow in responding to connect request; caused UI to freeze.
  * change request process to separate thread
  Logbook compile warning
  * replace strncpy with "*comma_position ="
* Sun Nov  1 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.15
  Doxygen cleanup
  * Clean up warnings on Doxygen txt files
  documentation update
  * remove deprecated pages
  * reorganize Table Of Contents
  * insure no missing page references
  VUmeter
  * add VU style input signal level monitor to main dialog
  - shares space on status bar
  * modify vumeter class to allow widget resize and partial
    display of 130 db Vu scale.
  * restore state of main dialog vumeter on startup
  * update documentation
  W1AW-macros
  * Add <LOCAL>
  * use local time for all subsequent scheduling macros
  * add macro tag <BUFFERED>
  - transmit characters are saved to and retrieved from
    a hidden text buffer.
  - prevents user from moving Tx cursor into middle of
    macro which causes macro to pause
  - Tx panel text is used if <BUFFERED> not present in the
    macro text
  * fix Farnsworth WPM macro tag
  County Lists
  * added Alberta, Saskatchewan
    xmlrpc rig timeout
    kml
  DXCC lookup
  * Change all references to "United States" to USA
    status locale
    Level indicator
  FeldHell
  * Fix font resize bug
  - caused intermittent seg fault
  - caused loss of raster
  hamlib NET
  * fixes for connecting to rigctld from fldigi
  * added "Default" button to hamlib configure panel
  NanoIO
  * MORTTY V4 compatibility changes
  cluster dupcheck
  * add dupcheck to dxcluster CALL select
  ADIF Conformity
  * The ADIF-specification defines number-values as dot-separated.
  * Localization seperates by comma on non-english systems. This
    changes the behavior to dot separation in the FREQ-value.
    XmlRpc Exit
  Navtex
  * Fix and simplify the correlator
  - Make sure the correlator only ever jumps +delta or -delta to
    the early or late accumulator, and never the long way around.
  - The adjustment limiting code had a bug that never seemed to break
    anything; simplify that code by removing the special case.
  * fixed memory leaks, simplifiedexit code, improved C++17 compatibility
* Mon Jul 20 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.14
  fonts
  * modify start up font enumeration
  - sort system fonts with qsort
  - enumerate fixed fonts
  - add fixed/all selector to font selector
  - use static class members []
    . instantiated and initialized on first instance
    . deleted when all instances deleted
  * change FreqControl width sizing to one based on widest
    numeral for selected font.
  Navigator
  * Fix missing initialization code for Windows OS
  hamlib
  * changes driven by hamlib 4.0
  Build scripts
  * remove -lregex from mingw cross compile scripts
  localtime_r
  * add timeops.h to n3fjp_logger.cxx
  Freq Analysis
  * Add Rx RIT control
  - apply as linear correction to observed frequency
  * Disable rxppm corrections when frequency analysis modem
    is active
  Field Day Logger
  * Fix reconnect to server when changing bands/modes
  flarq update
  * Replace text widgets with fl_input2 and F_Edit widgets.  Adds
    UTF-8 character handling.
  * Add restoration of beacon after cessation of ARQ exchanges
  * Modify fldigi to correctly display UTF-8 characters during
    both transmit and reception of flarq text
  Navtex
  * Fix crash in navtex code
  * remove the NOSIGNAL state.
  * make early/prompt/late detector able to lock onto more signals
  Sound Record
  * Insure that audio recordings have .wav extension
  Freq Control
  * change to use unsigned long to represent the frequency value
    maximum value increased to 4294967295 (2^32-1)
  Cabrillo logs
  * correct Cabrillo report MODE entry
  sound.cxx warning
  * fix compile warning on indentation
  SNDFILE
  * change SNDFILE to a required library
  FSK HELL
  * invert video reversal on HELL 80
  * rename FSK_HELL -> FSKH245
  * set default filter bandwidth for each mode
  Store/Recall
  * Change Store/Recall menu items to mode_info[].name vice
    mode_info[].sname
  wefax
  * Change bandwidth selections
  Rx Monitor
  * Add test for existence of filter in monitor playback
* Wed May 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.13
  doxygen
  * add new documentation files
  cw prosign
  * fix loss of prosign AA
  - conflict with Northern European accented characters
  Analysis mode
  * Add Zulu time readout to status bar
  Debug Sources
  * remove bMOREINFO
  * add "Data Load" toggle to Debug sources
  * add "Synop" toggle to Debug sources
  * add "KML" toggle to Debug sources
  * remove deprecated command line parameters
  - --debug-pskmail, use debug source ARQ
  - --debug-audio, use debug source AUDIO
  * redesign Event Log dialog to make selection of level and
    sources more intuitive
  wefax
  * Modify phasing algorithm to measure, analyze and act upon
    ratio of white and black intervals.
  * Change default center frequency to 1900. Allows detection
    of start tone @ 300 Hz, stop tone @ 450 Hz.
  * Simplify FM detector.  Use complex functions vice I/Q logic
  * Redesign user interface
  - always use internal Rx panel
  - always use external Tx dialog
  - move infrequently used controls to configuration dialog
  * Rewrite pic and image classes
  * Add user correlation control to config panel
  * Correct transmit methods
  - Start/Stop signals not in spec
  - Transmit duration computation resulted in very long
    transmission
  * update documentation
  README update
  * update reference to winfldigi
  fedora 64 build
  * remove Fl::wake calls that require void* data
  * replace with REQ qrunner calls
  Code cleanup
  * remove extraneous debugging lines from code
  fsq sounder
  * restore sounder when starting FSQ from another modem
  Default event log level
  * restore INFO as default
  * change socket events to VERBOSE
  rx_extract
  * imrove behavior servicing multiple instances of flmsg
* Thu Apr 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.12
  TX auto RST-sent
  * add control-shift-s for inserting RST sent value in TX stream
  CW/DTR/RTS
  * restore missing Nordic characters on DTR-CW
  * enable PTT during CWIO processing
  * allow user to calibrate DTR-CW timing at nominal WPM
  - fractional computed values rounded to nearest integer
    i.e. round(0.5) => 1
  * update documentation
  File/Audio
  * File selection caused cessation of audio processing while
    waiting for user selection.  Results in cessation of signal
    processing including keep alive signals to flamp and flmsg
    if linked.
  - move all UI interaction to main thread
  trx testing
  * replace compiler macros with in-line code to aid in
    debugging
  AFTER macro
  * add AFTER tag to repeat macro after a delay of NN seconds
  CWID button
  * One more time to wrestle the wayward CWID button to the mat
  - fluid definition file "confdialog.fl" OK
  - needed to execute "make flgen" to create new
    confdialog.cxx/h files
* Fri Apr  3 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.11
  * Bug fix release only - no functional changes
* Wed Apr  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.10
  AWOL CW id button
  * Fixed "hidden" state of CW ID button
  Macros
  * Restore execution code for <TUNE
  * Retain delayed execution code for <!TUNE
  * Create new macro <@TUNE
  * All three versions allow tune interval to be spec'd
    in fractional seconds, i.e. 2.5, 5.1 10.0 15
  * <TUNE:nn.nn> used alone returns to receive
  * <TUNE:nn.nn> followed by tex1t remains in transmit
    to complete the transmission.
  * Examples:
    + <TUNE:10.0>
    + <TUNE:5>
    <TX>tune test <!TUNE:1.5> de w1hkj k
    <RX>
    <@TUNE:2.5>
  * Remove text size restriction on CPS test report.
  RigCat config
  * restore missing control labels
  CW 5 wpm
  * 5 wpm farnsworth speed demands larger OUTBUFSIZE
  - increase output buffer to 65536
  audio alert
  * fix seg fault
  - test for existence of audio_alert instance
  analysis mode
  * changes to data file output
  flrig auto off
  * add ability to shutdown flrig/xcvr during fldigi shutdown
  maclogger
  * correct interpretation of UDP frequency string
  * update transceiver frequency based on UDP frequency
  mkappbundle
  * modify 'version' to include patch level
  nanoIO
  * Correct TTY interface code
  start/stop transitions
  * add code to soften the start/stop transitions for all modems
  CW DTR-RTS
  * generate CW on selected DTR/RTS signal line
  * CW DTR/RTS signals generated concurrent with AF counterparts
    and within a separate thread.
  Olivia 2 tones
  * correct trailing edge cutoff of postamble tones
  Xmlrpc Xcvr
  * enable QSY when Xmlrpc client xcvr is connected
  mp3
  * simplify mp3 conversions
  - test for file access using fopen
  - use linear sample rate converter
  contestia cr
  * correct suppression of <CR> display
  serial port
  * insure that DTR and RTS are always disabled when closing port
  Check Version
  * correct version check logic
* Sat Jan 18 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.09
  * Alert/Rx-monitor playback
  * Dialog closure
  * PO updates
  * config-dialog-mod
  * cw mods
  * MilliSleep
  * New Install
  * Audio alerts disable
  * Winkeyer
  * lotw mangled report files
  * Analysis mode
  * ARRL CW bulletins
  * hamcall
  * RSID code assignments
  * tree metaphor
  * Log ADIF export
  * xmlrpc_rig
  * Rx monitor
  * Display Logbook Datum
  * RTTY bell
  * Combo Box behavior
  * cw prosigns
  * CW International Chars
  * Xmt Audio file
  * Alerts
  * Data file update
  * Wefax autosave
  * flrig freq/mode
  * Update check
  * WEFAX AFC
* Mon Aug 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.08
  - Greek translation files updated by Haris SV1GRB
  - xmlrpc <vector>
    . This reverts commit d681ab54b31100878e16bf2c8c2b9a96ceb2de23.
    . avoid sizing a zero length vector; use resize(size, n) for
    non empty return vector
  - Documentation
    . Add missing deadman timer documentation
  - Raster init values
    . Raster::resize() was being called with a negative
    width or height due to bad state being stored in the
    config.  This resulted in fldigi crashing before the
    UI was displayed.
    . submitted by Stephen Hurd <shurd@FreeBSD.org>
  - Image transmit docs
    . Correct manual for thor, mfsk, ifkp and fsk image transfer.
* Thu Aug  8 2019 Martin Hauke <mardnh@gmx.de>
- Udpate to version 4.1.07
  * FL_LOCK
  * wf mods
* Tue Jul 23 2019 Martin Hauke <mardnh@gmx.de>
- Udpate to version 4.1.06
  * nanoIO
  * FD server disconnect
  * Calendar
  * Warnings etal
* Wed Jul  3 2019 Martin Hauke <mardnh@gmx.de>
- Udpate to version 4.1.05
  * LoTW fllog
  * Modem macro
  * Close Logbook
  * eQSL
* Wed Jun 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.04
  * add debug statements to track access to remote log server
    xmlrpc <vector>
  * fix for zero length byte vector instantiation on Fedora global
    build LoTW delivery
  * Change to testing for LoTW delivery status Apple kill button
  * force coordinated shutdown for command-Q, red-X decoration button,
    or File/Exit process main dialog title
  * force Windows to update window title when connecting to ACL
    Contestia/Olivia
  * Add contestia submodes to contestia modem type - needed to
    enable rsid contestia submode detection
  * Add missing submodes to Olivia Warnings
  * correct warnings discovered by newer 64 bit compiler Log reports
  * correct output formatting of text and csv reports Documentation
    update
  * update contest section 7qp multi
  * Parse multi state/county report strings n3fjp
  * restore named digital modes to MODE entry passed to loggers.
  * restore ALC compatible controls CALL, FREQ, BAND, MODE, NAME,
    QTH, STATE/PROVINCE, COUNTRY, GRID, POWER, COMMENTS, DATE,
    TIME-ON, TIME-OFF wfonly controls
  * correct control positioning
  * allow visibility of Rev, Store, Lock controls Read log debugging
  * Added event logging statements to the read log file function.
  * Add wait for modem change to the execute method pMODEM(...)
    DE QSO Party
  * Add Delawre QSO party to configurable contests
* Sun Jun 16 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 4.1.03
  * correct wf update loop
  * Disable WinKey serial echo for emulators like K3NB Arduino sketch.
  * modify default CQ macro to include RsID on/off
  * Add code to correctly recognize OLIVIA submodes
- Update to version 4.1.02
  * change to allow concurrent timed dialogs
  * insure that multiple dialogs do not overlie each other on UI
  * remove multiple goto's on RsID detection notification dialog
  * correct resizeing of timed dialog
  * separate eQSL / LoTW alert dialogs instances - allows both to
    be visible concurrently
  * ignore multiple RsID notifications when notifier dialog is
    visible
  * display eQSL notifier when operating with external fllog
  * deprecate the xmlrpc rig control tab
  * add event log to waterfall only UI
  * add VERBOSE events to all xmlrpc calls
  * change waterfall redraw processing to timed updates,
    independent of trx thread timing
  * Language update: add pl.po changes
  * Documentation update
  * Add "N3FJP Amateur Contact Log" to title bar when
    connected to external logger
  * CQzone: add to xmlrpc add_record method
  * trx_xmit_wfall_draw: change thread test to TRX_THREAD
    vice MAIN_THREAD
  * Log rotation
  * Secure METAR
  * lgbook File: add code to populate the logbook dialog widget
    txtLogFile "File:"
  * remove C style memory functions from qzlib implementation
  * add limits testing on get_word method to prevent
    stack corruption
  * add MY_CALL, OP_CALL, MY_QTH and MY_LOCATOR fields to ADIF
    xmlrpc record
  * QTE-QRB: Make hover over Rx panel CALL text work with
    external fllog
  * Update globals entries for OLIVIA modes / submodes
  * add logbook backups
  * ARQ server: correct logic for testing loss of client
  * Update log dates when fldigi submits either eQSL or LoTW
  * XmlRpc Log Dup Check: Change for tri-state return from
    xmlrpc duplicate test
  * change flrig ptt keys modem default to false in configuration.h
  * DxCluster/N3FJP i/o: changed method calls to agree with socket
    class changes
  * corrected multiple "connection refused" dxcc connect attempts
  * only submit eQSL / LoTW if set in configuration
  * update submit date eQSL
  * modify build.m4 and src/Makefile.am to suppress bogus
  - fvisibility-inlines-hidden warnings during cc compilation
    of mbedtls source.
  * changes to isolate notify_dialog from invoking thread
  * MODE export: allow log database to export non-fldigi modes
    such as FT8
  * add flarq_socket.cxx - insulate flarq build from fldigi includes
  * Add eQSL field to export data
  * Add timed eQSL delivery status message dialog
  * Add sub mode export if valid ADIF entry
  * tod clock start move to after debug init
  * ARQ socket i/o: Increase debug text size to accommodate large
    arq texts from flamp.
  * ARQ socket i/o: Insure that data streams are always bound to
    data blocks
  * ARQ socket i/o:   prevent receive socket buffer overruns
  * ARQ socket i/o: correct TOD clock
  * analysis mode: add signal amplitude to output csv file
* Tue Feb 19 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 4.1.01
  * CW h/w ptt
  * nanoIO
  * NAVTEX abort
  * dup-check
  * ADIF submode
  * WF only bug fix
  * LotW
  * Pedantic warnings
  * SD counties
  * QRZ.com
  * SV1GRB test report
* Tue Jan 29 2019 mardnh@gmx.de
- Update to version 4.1.00
  * po update
  * WWV doc
  * Winkeyer FSK
  * Contests
  * arq-override
  * flmsg-dir
  * contest-docs
  * fldigi_def.xml
  * socket_mods
  * Fltk 1.4 mod
  * wefax
  * nanoIO
  * CW SOM table
  * flrig: macro
  * Audio adjust docs
  * feldhell
  * C-11 fixes
  * nano FSK
  * Mint-19/Mate
  * Signal Browser documentation
  * flrig seg fault
* Sat Aug 18 2018 mardnh@gmx.de
- Update to version 4.0.18
  * CPS testing
  * ipv6 addressing
  * MT63 centering
  * fsq mods
  * IFKP/THOR greyscale image
  * Hamlib bug fix
  * Tooltip
  * nanoIO
  * THROB adif
  * RigCAT dialog
* Wed Jun 13 2018 mardnh@gmx.de
- Update to version 4.0.17
  * flarq idtimer
  * Greek language update
  * tmpfile
  * xmlrpc cat string
  * Modem start frequency
  * Serial port discovery
  * Log entries
  * flarq appdir
  * rx/tx
  * RTTY Quick pick
  * quick pick rtty baud
  * Documentation Update
  * CW/FSK I/O on start
  * WinKey PTT
  * Navigator
  * nanoIO
  * Default Lighted Button
  * ST/PR macro tags
  * K2/K3/KX3 data modes
  * Logbook read
  * 8pskF
  * fsq/ifkp audit logs
  * RTTY browser decode
* Sun Feb 11 2018 mardnh@gmx.de
- Update to version 4.0.16
  * wo seg fault
  * 8psk lockup problem
  * Miscellaneous menu
  * pskrep autostart
  * Grid Square Contest
  * Logbook Export
* Sat Jan 20 2018 mardnh@gmx.de
- Update to version 4.0.15
  * ARQ server
  * Signal gain
* Tue Jan 16 2018 mardnh@gmx.de
- Update to version 4.0.14
  * linux shutdown
  * remote logbook
  * ARQ exit seg fault
  * WEFAX auto center behavior
  * WEFAX phasing change button
  * RTTY configure initializers
  * File aging
  * PSK IMD
  * Spectrum Display
  * Warnings in sound.cxx
* Sat Dec 30 2017 mardnh@gmx.de
- Update to version 4.0.13
  * Language Translation
  * cw t/r - doc update
  * Spectrum Analyzer
  * TS990 tune feedback
  * OS X CW
  * FSQ/IFKP clear tx panel
  * deadman
  * Image transmit
  * flrig race
  * CW Sweepstakes
  * CW no tx char
  * timeops
- Run spec-cleaner
* Mon Dec 11 2017 mpluskal@suse.com
- Small package cleanup
- Do not use scriplets on Factory where they are not needed anymore
- Run tests during build
* Mon Dec 11 2017 crrodriguez@opensuse.org
- BuildRequire pkgconfig(x11) not xorg-x11-devel
* Wed Nov  1 2017 mardnh@gmx.de
- Update to version 4.0.12
  * Farnsworth timing
  * PSK sinc filter
  * ACL interface
  * Text capture
  * OSX start process
* Sun Oct 15 2017 mardnh@gmx.de
- Update to version 4.0.11
  * Text Capture
  * FreeBSD mod
  * Documentation update
  * PSK filter
  * Audio Stream
  * printf cleanup
  * CW Multichannel
  * QSY multi
* Sun Oct  1 2017 mardnh@gmx.de
- Update to version 4.0.10
  * WX HamQth bug fix
  * win7 mingw build fixes
  * wefax ui mods
  * wefax_map
  * auto start
- Update to version 4.0.9
  * doc update
  * clock_gettime
  * spectrum display
  * Test Signal Dialog
  * dxcluster fonts
  * smod
  * Spot buffer
  * Winkeyer clones
  * PSK s/n imd
  * RX Text capture
  * PSK viewer
* Sun Aug  6 2017 bwiedemann@suse.com
- Override build date, user, hostname to fix build-compare (boo#1047218)
* Sat Jul 22 2017 mardnh@gmx.de
- Update to version 4.0.8
  * Fix OS X path name to executable when SPACE chars are in path name
  * Fix Flex serial interface problem
  * rigCAT metering
    Change to allow multiple scale points in both Smeter and Power
    meter OS X autostart Fix crash if autostart file name points
    to a non existent folder
  * RigCAT i/o
  - Fix missing mutex's on sendCommand
  - Modified SCU-17 stop bit fix; DCB.stopbits must be 0 on 2nd port
  * XMLRPC rx stream
  - Correct missing CW rx stream characters to xmlrpc rx.get_data call
  * RX text paste
  - Add code to disallow pasting text into the Rx text widget
  * FSQ triggers add mycall test for FSQ triggers FSQ image
  - fix fsq tone deafness after receiving image
* Sun Jul  9 2017 mardnh@gmx.de
- Update to version 4.0.7:
  * Add SCU-17 select for separate serial port PTT.
    SCU-17 second COM port requires stop bits to be set
    to ZERO, or the Windows driver fails to give access
    to the DTR / RTS controls.
  * bindUDP
  * Issue with bindUDP using IPv6 calls
* Mon Jun 26 2017 mardnh@gmx.de
- Update to version 4.0.6:
  * flmsg alert - added enabled test
  * Time Macros - Corrected <LT> format string
  * Require PortAudio - fail compilation if portaudio not detected
  * documentation update
* Wed Jun 21 2017 mardnh@gmx.de
- Update to version 4.0.5:
  * Change to support IPv6 sockets
  * PTT selectable on N3FJP interface
  * Selection of full/half duplex audio interface
  * Macro and audio alerts enabled for FSQ modem
  * Audio alerts for pre and user defined events
  * Added warning dialog to Restore configuration button
  * CW user selectable squelch attack/decay
  * CW Extended UTF-8 Morse characters
- Remove patch:
  - fldigi-license.patch (fixed upstream)
* Tue Jun 13 2017 mpluskal@suse.com
- Update to version 4.0.4:
  * cw scanner
    + adds multi signal scanner / browser
    + Sound Card
    + keep input and output sound card devices open for duration
    of fldigi execution
    + Corrected tune output device
    + Changed tune, wfid, video and cw-id to use tx offset
  * CW QSY
    + Correct QSY when transceiver in CW and CW-R type modes
  * CALL field size
    + Increased CALL, OP_CALL, STA_CALL from 15 to 30 chars
  * LOG area controls
    + Resize controls to add County entry control.  Allow user
    to select which extra qso field is displayed; country or
    county.
* Tue Jun 13 2017 mpluskal@suse.com
- Add fldigi-license.patch to fix obvious typo in license
* Sun May  7 2017 jengelh@inai.de
- Strip redundant parts from description.
* Wed May  3 2017 mardnh@gmx.de
- Update to version 4.0.3
  + OS X Wizard
  + cw decoder
  + CW wait
* Mon Apr 24 2017 mpluskal@suse.com
- Split lang subpackage
- Add dekstop file scriplets
* Sun Apr 16 2017 mardnh@gmx.de
- Fix Url
- Use pkgconfig-style for BuildRequires
- Specfile cleanup
* Sat Apr 15 2017 dl8fcl@darc.de
- update to version 4.0.2
  see readme.txt
* Tue Mar 28 2017 dl8fcl@darc.de
- update to version 4.0.1
  see readme.txt
* Mon Jan 30 2017 dl8fcl@darc.de
- update to version 3.23.21 - Maintenance release
  see readme.txt
* Tue Jan 10 2017 dl8fcl@darc.de
- update to version 3.23.20 - Maintenance release
  see readme.txt
* Sat Dec 24 2016 dl8fcl@t-online.de
- update to version 3.23.19 - Maintenance release
  see readme.txt
* Tue Dec 13 2016 dl8fcl@darc.de
- update to version 3.23.18 - Maintenance release
  see readme.txt
* Thu Dec  8 2016 dl8fcl@darc.de
- update to version 3.23.17 - Maintenance release
  see readme.txt
* Mon Nov  7 2016 dl8fcl@t-online.de
- update to version 3.23.15 - Maintenance release
  see readme.txt
* Sun Sep 18 2016 dl8fcl@darc.de
- update to version 3.23.14 - Maintenance release
  see readme.txt
* Sun Aug  7 2016 dl8fcl@t-online.de
- update to version 3.23.13 - Maintenance release
  see readme.txt
* Sat Jun 25 2016 dl8fcl@darc.de
- update to version 3.23.12 - Maintenance release
  update to Polish translation file, pl.po
  xmlrpc add_tx
  * restored original text.add_tx
  * added text.add_tx_queu to add text to hidden
    transmit queu ... used with flmsg arq
  mfsk xmt filter
  * disabled mfsk xmt filter
  FSQ msg append
  * Add configuration item to allow user to select
    "always append" when saving a # directive message
  FSQ IFKP heard lists
  * Correct FSQ rxtext parsing for heard discovery
  * Change management of heard list for both FSQ and IFKP
  waterfall group
  * remove +2 from waterfall group height
  thor image
  * repaired send image button function
  RxID button
  * set startup color
* Mon Jun 13 2016 dl8fcl@t-online.de
- update to version 3.23.11 - Maintenance release
  A lot of bug fixes and improvements - see ChangeLog
* Tue May 31 2016 dl8fcl@t-online.de
- update to version 3.23.10 - Maintenance release
  A lot of bug fixes and improvements - see ChangeLog
* Mon Apr  4 2016 dl8fcl@t-online.de
- update to version 3.23.09 - Maintenance release
  FSQ variable Rx
  * Enable FSQ variable RX
  * Enable allcall(#) menu item for sending file to allcall
  Export ADIF_NAME
  * added FLDIGI_MODEM_ADIF_NAME export variable to environment exports.
  WF only
  * correct for missing reference to power level control
  DnD Image
  * Add Dnd Image to TX panel
  - applies to MFSK, IFKP and THOR image transfers
  - allows operator to insert image processing into TX text stream
  - drag-drop image from system file viewer to TX text panel
  - updated specific modem documentation
  Documentation
  * Correct 'M>' to 'Store' in description of the Store button
  * Amend help file for the frequencies list usage
  Frequencies2 use string
  * added use descriptor string to frequencies2 list
  About
  * update developer list
  View noise
  * send signal / noise composite audio to waterfall during transmit
  - valid when using --noise command line parameter
  Sanitize tile_x, tile_y startup values
  * Fixes: LP: #1478358
  - https://bugs.launchpad.net/ubuntu/+source/fldigi/+bug/1478358
    "fldigi 3.22.13 crashes on start-up when tile_x is large"
  - also applies to 3.23.xx branch
  - this fix prevents a user from editing the fldigi.prefs file
    with out of range values.
  NAVTEX update
  * change the distance between early, prompt, and
    late accumulators to be an integer number of samples.
  * noise and QSB processing
  - average the accumulator values over a longer time period
  - tighten bit tracking feedback loop
    .signal lock takes a little longer
  * make the AFC window a little wider to deal with some signals.
  * instead of requiring 5 consecutive correct characters
    to start decoding, store a stream of bit confidence values and
    require 9 good ones out of 14 total. FEC can take care of the rest.
  * add FEC calculations to do single bit permutations on
    bad characters, flipping the bit with the lowest confidence value.
  * code cleanup - remove unused variables.
  RxID enhancement
  * Add right click pop-up menu
  - PASSBAND - check box ON/OFF
  * Color code ON illumination for
    PASSBAND ON/OFF
  TX timer
  * Added TX timer display to the menu bar
  rigcat mod
  * Add min, max settings for pwr control
  * Add testing mode if no xcvr serial port available
  * Made opMODE and opBW combo controls readonly
  - pull down values can only be added and not inserted
  * Added debugging tags to xml definitions:
  - <NOSERIAL>true/false</NOSERIAL> - default false
    suppress all serial port i/o
  - <ASCII>true/false</ASCII> - default false
    if true, print all CAT i/o events as ASCII strings
    if false, print all CAT i/o events as HEX sequences
  * Added polling for pwr level query
  PSK IMD
  * add IMD generator
  * modified IMD computation for continuous operation
    vice only during DCD
* Thu Feb 25 2016 dl8fcl@t-online.de
- update to version 3.23.08 - Maintenance release
  NAVTEX update
  * low pass mark & space individually
  * Use ATC and fft-filters adapted from RTTY modem
  * Correct display metric
  * Widen afc filter for 'jump 90 Hz' code
  * Use exact bit length
  * Calculated sync modification
  * see src/navtex/navtex.cxx for design analysis
  Save Logbook
  * Change system dialog invoked when saving logbook to
    system save-as vice save.
  Analysis mode
  * Restore <CSV:on, <CSV:off, <CSV:t(oggle)
  flrig PTT
  * All user to select whether flrig PTT change triggers
    RX/TX change in modem stata
  flrig waiting
  * Changed event recording level for
    "Waiting for flrig" from INFO to VERBOSE
  COM port close
  * change effects the Windows COM port close process
  - rigCAT startup process no longer dependent on order, xcvr
    can be started before or after fldigi is running.  Tested
    by Haris, SV1GRB.
  Mac Logger
  * Added UDP interface to read data exported by MacLogger
  - UDP data stream on socket 255.255.255.255 / 9932
  - User configurable items:
    . enable/disable UDP socket reads
    . Capture and use UDP Radio Report data
    . Capture and use UDP Spot Tune data
    . Capture and use UDP Spot Report data
    . Capture and use UDP Log Report data
    . Capture and use UDP Lookup Report data
    . Enable UDP string capture to file
    file in fldigi files/temp folder
    filename: maclogger_udp_strings.txt
  * Added <signal.h> to threads.h to avoid missing reference
    to sigemptyset in some gcc installs
  fsq repeat last
  * test for empty list of previous command
  GCC 6 build
  * GCC 6 defaults to -std=gnu++14, and attempting to build fldigi fails
    with a number of errors. One is that C++11 added std::next and so
    because of the "using namespace std" in src/fsq/fsq.cxx the global
    variable 'next' and std::next are ambiguous. That can be easily solved
    by qualifying ::next or adding using ::next at function scope.
  * The other errors are due to the different return type for
    std::complex<T>::real() and std::complex<T>::imag() in C++11 and
    later.
  CALL capture
  * add copy call to clipboard when capturing from Rx text
  Scope View
  * Corrected saved position/size status values
  RigCAT modifications
  * Separated no xcvr functions from rigcat loop operation
  * Corrected hamlib start/stop process to prevent
    lockup when xcvr is not responding to CAT commands
  - hamlib still creates a zombie process when trying to access
    a bogus serial interface such as a bell modem
  * Added string / hex data LOG view
    <LOGSTR>true/false</LOGSTR>
  * Added variable loop timing
    <POLLINT>100...20000</POLLINT>
    default 100 msec
  * Corrected use of BW-REPLY and MODE-REPLY in xml def file
  * Added ability to read and display Smeter and Pwr meter
  * Added debugging statements to exit functions
  * Fixed aberrant save frequencies2.txt file behavior
  * Added manual notch read/write using waterfall
    notch filter interface
  * Added power level control for xcvrs with that CAT command
  - set power level also used for logging
  * Updated tutorial on transceiver xml definition file structure.
  * Added <VERBOSE>bool</VERBOSE> specifier
  - use during development of an xml file
* Sat Feb  6 2016 dl8fcl@t-online.de
- update to version 3.23.07 - Maintenance release
    Exit delays
  * thread shut down processes to provide additional logging info
  * speed up shut down process
    Contest fields
  * Adjust width of exchange in logging field
    OS-X start_process
  * Add App recognition
    LOG RECORD exports
  * Added these log entry variables to the export environment list
  - FLDIGI_LOG_STATE
  - FLDIGI_LOG_COUNTRY
  - FLDIGI_LOG_SERNO_IN
  - FLDIGI_LOG_SERNO_OUT
  - FLDIGI_XCHG_IN
  - FLDIGI_XCHG_OUT
  - FLDIGI_VE_PROV
  * Added LOGBOOK log entry variables to the export environment list
  - FLDIGI_LOGBOOK_CALL
  - FLDIGI_LOGBOOK_NAME
  - FLDIGI_LOGBOOK_DATE
  - FLDIGI_LOGBOOK_TIME_ON
  - FLDIGI_LOGBOOK_DATE_OFF
  - FLDIGI_LOGBOOK_TIME_OFF
  - FLDIGI_LOGBOOK_RST_IN
  - FLDIGI_LOGBOOK_RST_OUT
  - FLDIGI_LOGBOOK_FREQUENCY
  - FLDIGI_LOGBOOK_MODE
  - FLDIGI_LOGBOOK_STATE
  - FLDIGI_LOGBOOK_VE_PROV
  - FLDIGI_LOGBOOK_COUNTRY
  - FLDIGI_LOGBOOK_SERNO_IN
  - FLDIGI_LOGBOOK_SERNO_OUT
  - FLDIGI_LOGBOOK_XCHG_IN
  - FLDIGI_LOGBOOK_XCHG_OUT
  - FLDIGI_LOGBOOK_QTH
  - FLDIGI_LOGBOOK_LOCATOR
  - FLDIGI_LOGBOOK_QSL_R
  - FLDIGI_LOGBOOK_QSL_S
  - FLDIGI_LOGBOOK_NOTES
  - FLDIGI_LOGBOOK_TX_PWR
  - FLDIGI_LOGBOOK_COUNTY
  - FLDIGI_LOGBOOK_IOTA
  - FLDIGI_LOGBOOK_DXCC
  - FLDIGI_LOGBOOK_QSL_VIA
  - FLDIGI_LOGBOOK_CONTINENT
  - FLDIGI_LOGBOOK_CQZ
  - FLDIGI_LOGBOOK_ITUZ
  * Enable temp/log.adif for all OS, was just WIN and OS X
    HAMLIB CW RTTY
  * provide selectable sideband sense selection for CW and RTTY
    PSKR metric
  * Fixed erroneous metric computation when received signal is zero
  - error apparant when testing with CODEC that has no applied audio
  - bug report by Per Crusfalk, SM0RWO
    PSKR/8
  * Fix segfault if starting pskbrowser in any of the pskr or 8psk modes
    Audio adjust
  * Added Tx/Rx audio adjustment details
    WEB query
  * Moved URL strings for various web call sign queries to progdefaults
    configuration.
  - updated hamqth to https address for browser lookup
    Mode Set
  * Changed mode_set logic to use std::string vice null terminated C string
  * Changed modes to size NUM_MODES vice NUM_RXTX_MODES.
    Tab key docs
  * Added illustration and emended text describing Tab key operation
    in the Tx text buffer.
    hamlib PTT_ON_DATA
  * changed PTT_ON to PTT_ON_DATA in call rig_set_ptt
    Macro Tool Bar
  * Correct edit / launch behavior of 4 row toolbar
  - removed dependency on 2 bar selection of alternate
    macro set
    XmlRpc client update
  * Corrected passing hi/lo cutoff values for supported transceivers
    such as the TS2000.
  * Added macro tags <RIGLO:nnnn>  <RIGHI:nnnn> which make flrig requests
    to respectively set the lo-cut and hi-cut transceiver DSP filter settings.
  * Added get_sideband xmlrpc call to modified flrig
    Log Notes
  * Added control for user selection of clearing/retaining data in
    notes field after remote database query.
    Misc Updates
  * correct WF hesitation when processing post Tx macros
  * remove xmlrpc_rig ptt transition waiting from main loop
  * correct WF hesitation when transmitting MT63 start tones
  * added CTRL-nnn numeric sequence character entry to Fl_Input2
    class.  Allows direct entry of characters such as ñ in
    QSO fields, macro editor, etc.
  * added new menu items to FTextEdit and Fl_Input2 widgets
  - allow user to select UTF-8 special characters from
    pop-up menu (right click in widget).  This effects
    TX text widgets and all data entry controls which use
    the Fl_Input2 widget.
    Set Frequency
  * Added code to update waterfall when changing vfo frequency
    from fldigi / flrig
    Rx SaveAs
  * correct Rx panel "Save text as..." end-of-line sequence
* Fri Dec 11 2015 dl8fcl@darc.de
- update to version 3.23.06
  * give priority to flrig xmlrpc support independent of any other
    configuration setting for rig control - dependent on fldigi
    detecting an flrig compatible xmlrpc
  * add test for xcvr response loop to set_ptt
  * added XMLRPC_DEBUG with time signature Waterfall only
  * fix segmentation fault introduced by addition of 4x12 macro matrix
  * Added resize methods to both classes; corrects displaced smeter
    and power meter
  * update of documentation
* Mon Nov 23 2015 dl8fcl@t-online.de
- update to version 3.23.05
  * disabled kml services unless user enables on kml configuration
    tab. default is ON
  * add dockable macros in a 4x12 matrix
  - provides access to all 48 macros.
  - group of 48 can be dragged to/from it's default position
    just below the main menu bar
  * change vertical raster height to 20 vice 60
  - decreased minimum vertical main dialog dimension for small
    netbook screens
  * update to documentation
  * Add code to allow on the fly correction of corrupt ADIF records
    during file read.
  * Added gpio support for PTT.
  - used primarily by Pi experimenters
  - submitted by Lior, KK6KWA
  * suppress info messages during prog start
  - prodigiuous use of LOG_INFO increases difficulty of
    debugging other aspects of fldigi
  - enable the INFO messages for debugging or to observe
    program flow by setting command line flag
  - more-info ; case is significant
  * Lowered CPU requirements to allow for use on Android/Netbook devices:
  - Added modes 125FL and 250FL with constraint length 13 FEC
  - Adjusted maximum traceback memory for viterbi decoder
  - Set traceback to an optimally-high value in viterbi.cxx constructor
  - 8PSK - 500F 1000F & 1200F now use only 1 viterbi decoder without voting
  - Assigned secondary RsID codes to 125FL and 250FL.
* Thu Oct 15 2015 dl8fcl@darc.de
- update to version 3.23.04 - Maintenance release
  * Corrected implementation of CW filter bandwidth
  * add image transfer to thor based on IFKP image processing
  - supported by THOR-11, THOR-16 and THOR-22
  - image modes are identical to IFKP images, fixed sizes and avatar
  * change update check location to Source Forge
  * change merge behavior when parsing unknown field name
* Thu Oct  1 2015 dl8fcl@darc.de
- update to version 3.23.03 - Maintenance release
  * Fix for FSQ trigger decode bug introduced by multiple
    directed station parsing
* Sun Sep 27 2015 dl8fcl@darc.de
- update to version 3.23.02 - Maintenance release
  FSQ updates
  * added cqcqcq button
  - casual users do not know to send cqcqcq vice
    cq cq cq
  * Updated on-line help
  * Increased allowable intervals for both sounder
    and heard-aging
  * Corrected repeated sounder to re-enable retries
    after a successful sounding.
  - sounder will wait until rx/tx state is RX
  - if Rx squelch is open then sounder will retry
    in 10 seconds.  Retry is repeated 10x before
    sounding is rescheduled for next interval.
  * Corrected text parser to accept multiple directed calls
  - w1hkj:efk2lbm w3fqn ka2cbc good morning all
    will now correctly accept k2lbm, w3fqn and ka2cbc as
    directed and display correctly in Rx text panel
  Other updates
  * Add definable delay to allow serial devices based
    on Arduino to not lock up in programming mode.
  * Run asciidoc with TZ=0 to make the footer datestamp independent of
    the build machine's timezone (for reproducible builds).
* Tue Sep 22 2015 dl8fcl@darc.de
- update to version 3.23.01 - Maintenance release
  * WX configure: corrected inchs mercury to Hg vice Mg
  * fixes for wfall-only operation (N1MM)
  * ifkp avatar: Added code to support variable image depth
    in png source file
  * correct bug in slant correction code of ifkp
  * Change read log routine
  - file read a line at a time vice entire image into RAM
* Sun Sep 20 2015 dl8fcl@darc.de
  update to version 3.23 - Major revison release
  * clear entire Tx panel when executing a ^r or ^R sequence.
  * add ability to disable start/stop tones in Olivia and
    Contestia
  * fix timer seg fault when Tx contains trash text
  * Incremental Frequency Keyed + modem
  - wide band, moderate speed differential MFSK signal
    with offset +1.
  - sample rate 16000
  - symbol length 4096
  - 33 tones spaced 3xSR/symlen apart approximately 398 Hz
    bandwidth.
  - multiple image transfer formats similar to FSQ
    . Avatar (59x74 WxH pixel) image transfers
  - tunable modem subcarrier (center freq)
    . may be configured fixed at 1500 Hz or
    . set to Psk sweet spot
  - raw data received written to audit log - if enabled
  - heard list entries written to heard log - if enbled
  - assigned fldigi secondary RSID code, (56, 1171)
  * Added @WAIT macro
  * Added disable macro timer when changing modems
  * WEFAX rx becomes unresponsive when writing to INFO log
  * code changes for update to mxe suite
  * Changed qsorec data store to an arrary of string pointers
    vice an array of strings.
  - new mxe implementation string handler changes from standard
  * change to "rb" for correct reading of logbook file
  - do not allow M$ to make changes to CR/LF counts
  * Add recognition of flrig LSB modes
  - adjust waterfall for LSB
  - correct logging frequency for LSB
    FSQ updates
  * Fix copy all on heard list
  * change default color scheme as requested by ZL1BPU
  - added user configuration items for RX text colors
  * remove "MONITOR" text from RX panel as requested by ZL1BPU
  * added fsq tx text queue to handle case when user
    tries to force a second transmit sequence when modem
    is already in TX state.
  * last_command updated to include both queued and transmitted
    text string.
  - allows recall of queued command even if transmit timed out
  * last_command changed to a stack of commands
  - allows recall of up to last 10 commands
  - each press of F2 recalls one deeper in stack
  - rotates back to beginning after recall of most ancient
  * add call to logbook using right click on heard entry
  * Fix erroneous date in audit log when fsq is default
    modem during program start
  - change format of date entry to make it easier to
    find when reviewing the log.
  * Added video text at beginning of transmit
  - also adds ability to transmit pretone
    for amplifier carrier detect
    for FM repeater operation
  * Add code to force center frequency to 1500
    when switching from another modem
  * Fix to avoid time out errors
  * Macintosh OSX thread management
  - submitted by KK5VD
  - Ensure FSQ TX routines are called in the main thread.
* Tue Jul 21 2015 dl8fcl@darc.de
- update to version 3.22.13 - maintenance/bug-fix release
  FSQ bug fixs
  * Fixed error in parsing returned heard list
  * Fixed save filename for # trigger
  - filename was not being saved with the .txt extension
  - append existing file
  * Changed time out processing of delayed response
  - added user configuration item for time out duration
  XMLRPC commands
  * Corrected interface values for
  - main.get_char_timing
  - main.get_tx_timing
  * Added following to xmlrpc struct
  - log.set_rst_in
  - log.set_rst_out
  * Added rig.get_frequency (d:n)
  * Deprecated main.get_frequency
* Sat Jul 18 2015 dl8fcl@darc.de
- update to version 3.22.12 - maintenance/bug-fix release
  FSQ heard parser, added more restrictive discovery of heard callsign
  - must pass crc8 comparison
  - must pass regular expression test for callsign
* Thu Jul 16 2015 dl8fcl@darc.de
- update to version 3.22.11 - maintenance/bug-fix release
  * added FSQCALL(US) compatible modem
  * corrected code-page 1250 Latin-1 extended character keyboard
    entry to UTF-8 strings
  * fix raise window problem when mouse passes over the freq
    control
  * fixed bug in exit procedure.  program failed to exit gracefully
    if TRX_STATE was RECEIVE
  * update to the interface for flrig control/query via xmlrpc
* Mon Jun  1 2015 dl8fcl@darc.de
- update to version 3.22.10 - maintenance/bug-fix release
  FTextView styles bug - Corrected order of calling reset_styles
  to prevent calling resize with an improperly initialized styles
  table
* Sat May 30 2015 dl8fcl@darc.de
- update to version 3.22.09 - maintenance/bug-fix release
  Fl_Text_Display, Avoid calling resize() too early
* Tue Apr 28 2015 dl8fcl@darc.de
- update to version 3.22.08 - maintenance release
  requires libflxmlrpc
* Fri Apr  3 2015 dl8fcl@darc.de
- update to version 3.22.07 - maintenance release
* Tue Mar 24 2015 dl8fcl@darc.de
- update to version 3.22.06 - maintenance release
* Sat Jan 10 2015 dl8fcl@darc.de
- update to version 3.22.05 - maintenance release
* Fri Dec 26 2014 dl8fcl@darc.de
- update to version 3.22.04 - bugfix realease
* Wed Dec 10 2014 dl8fcl@darc.de
- update to version 3.22.02 - bugfix realease
* Tue Oct 21 2014 dl8fcl@darc.de
- update to version 3.22.01 - bugfix realease
* Thu Oct 16 2014 dl8fcl@darc.de
- update to version 3.22.00 - major update
* Mon Jun 30 2014 dl8fcl@darc.de
- update to version 3.21.83, Maintenance release
  * Add user and programmer documentation
  * send STX, 0x02, signal when ARQ command to
    change modem is completed.
  * Added /opt/vttySn usage for Linux
  - create a linked name to a virtual port (socat)
    with link defined as /opt/vttyS0 ...
  * Changed defaults for new user to force
  - confirm exit, save configuration & macros on first use
  - prompt dialogs thereafter until user changes
    configuration dialog selections
  - added UI configuration to new install Wizard
* Thu May  1 2014 dl8fcl@darc.de
- update to version 3.21.82, Maintenance release
  hash-fix
  * fix compile warning on gcc post 4.5
  RnA Analysis
  * Change signal analysis mode to use DFT processing
    to determine best estimate of signal frequency
  * Moved freqanalysis.csv file to temp
  - changed name to analysis.csv
  * Resetting the WF frequency cursor deletes the analysis.csv
    file and restarts recording
  * Added macro control tag <CSV:on|off|t>
  - off - deletes file analysis.csv
  - on  - starts recording of analysis.csv
  - t (toggle) - changes on/off state of recording
  Phase accumulator
  * Corrected phase accumulator limits in cw, feld,
    dominoex and thor modems.
  Base Directories
  * Added FL_APPS directory recognition for placement
    of fldigi.files, NBEMS.files.
  - Linux : Changed from .fldigi to fldigi.files
  - Linux : Changed from .nbems to NBEMS.files
    includes programmatic change of existing directory
    names.
  WF Height/Speed
  * Increase max height to 500 pixels
  * Added control to select the SLOW drop speed
    factor.
  * Modified startup / resize code to avoid out-of-range
    resizing of critical widgets.
  RX Only
  * Added new xmlrpc commands
  - main.rx_only : Disables Tx.
  - main.rx_tx : Enables normal Rx/Tx operation
  * Added command line parameter --read-only; --ro
  RTTY mem leak
  * Closed minor memory leak in rtty.cxx, memory leak
    occured when
  - application closed or
  - baud rate / shift was changed
  Olivia/Contestia custom
  * Fixed indexing error in
  - set_olivia_bw, set_olivia_tones
  - set_contestia_bw, set_contestia_tones
    effects setting custom tones/bw from either
    macro or xmlrpc command string
  ARQ abort
  * Correct mutex deadlock during <cmd>abort</cmd> processing
  RTTY Custom Shift
  * Fixed custom shift selection
* Mon Mar 31 2014 dl8fcl@darc.de
- update to version 3.21.81, Maintenance release
    Spotter seg fault
  * bug fix to pskrep
    TX monitor
  * change default state of Tx Monitor to TRUE
  * change default level of Tx Monitor to 0.2
    Audio selectors for PORTAUDIO
  * correct ListBox offset in configuration panel
    M4 tr1 detect
  * add hash.m4 and supporting source code
    ttyACMxx identification
  * Added ttyACMxx USB serial port identification to serial
    port search.
    Olivia critical section
  * added critical section coding to protect encode/decode
    processing
    MT63 critical section
  * re-entrancy issue
  - must guard against changing processing parameters
    during encode/decode
    Logbook fields
  * Modified ordering of fields to prevent wrong
    lookup of fields associated with STX_STRING and
    SRX_STRING, the contest exchange fields
    Hamlib selector
  * Change from Combobox to Listbox
    Combobox
  * add to list when user enters a value
    RTTY macro
  * corrected width/baud/bits setting from macro tag
* Fri Mar 21 2014 dl8fcl@darc.de
- update to version 3.21.80, Maintenance release
    clang compatibility
  * correct istream return value
  * move tr1 to std
    FreeBSD nitems
  * Collision between Fltk-3.0 and FreeBSD system corrected
    in associated fluid definition file.
    Cabrillo time off
  * Limit to HHMM.  Logbook records to HHMMSS
    Change Fl_ListBox
  * Change to Fl_ComboBox for various controls
    which may require user entry.
    Restore Fl_Choice
  * Sound card device selection
    Olivia select fix
    fluid update
  * Prepare confdialog.fl for KISS implementation
    ComboBox
  * remove readonly attribute for input contol
* Tue Mar 11 2014 dl8fcl@darc.de
- update to version 3.21.79, Maintenance release
    RigCAT initialize
  * Add additional wait delays to accomodate transceivers
    and virtual serial devices that measure baudrate
  * Fixed flmsg/flnet correspondence bug
    Modem cleanup
  * Fixed a/d range issue with tx attenuator
    Choice-->ListBox
  * Changed all instances of Fl_Choice and Fl_Input_Choice
    to Fl_ListBox.
  - old Fl_Choice objects renamed to listbox_xxx
  - old Fl_Input_Choice objects renamed to i_listbox_xxx
  - Note that i_listbox_xxx objects need indexing offset
    to maintain compatability with progdefaults definitions.
  - New objects should use listbox_xxx naming convention.
  - This removes a rather ugly Fltk widget.  Fltk does not
    have a native ComboBox or ListBox widget.
    combobox-listbox
  * Update to combobox, Fl_ComboBox
  * Addition of listbox, Fl_ListBox
    RTTY normalize
  * Added code to normalize generated RTTY signal to
    maximum allowable signal amplitude
  * Added code to hard limit output signal to range of
    +/- 1.0
    Portaudio ring buffer
  * Increased size of portaudio ring buffer.
    Problem reported by Simon Gander, "I recently found
    out that the THROB1 and THROBX1 modes don't work
    correctly under certain circumstances. The pulses are
    too short and get cut off at the end, which in turn also
    causes the baudrate to be too high. I found out that I
    could fix the problem by increasing the size of the ring
    buffer in the SoundPort class.
    Portaudio error reporting
  * added code to provide addition details for
    portaudio failures
* Tue Feb  4 2014 dl8fcl@darc.de
- update to version 3.21.78, Maintenance release
* Wed Oct 30 2013 dl8fcl@darc.de
- update to version 3.21.77, Maintenance release
* Sat Sep 14 2013 dl8fcl@darc.de
- update to version 3.21.76, Maintenance release
* Tue Sep  3 2013 dl8fcl@darc.de
- update to version 3.21.75, Maintenance release
  Important update to RSID detector
* Sun Aug 18 2013 dl8fcl@darc.de
- update to version 3.21.74, Maintenance release
* Mon Jul 29 2013 dl8fcl@darc.de
- update to version 3.21.73, Maintenance release
* Fri May 17 2013 dl8fcl@darc.de
- update to version 3.21.72, Maintenance release
  changes in PSKMAIL, RsID Timeout, Colors/Fonts Dialog
* Thu May  9 2013 dl8fcl@darc.de
- update to version 3.21.71, Maintenance release
  Changed ARQ server / client management.
  Wavefile generate, MT63 mode selection,
  Signal Browser Colors, QRZ query, Rigsupport,
  eQSL url, PSKMAIL
  xmlrpc-c replaced by embedded xmlprcpp
  PO file update
* Sun Apr 14 2013 dl8fcl@darc.de
- update to version 3.21.70
  Contestia/Olivia
  * Quick change / custom dialog
  * Corrected Contestia callback in confdialog.fl
  * Corrected resetOLIVIA function
* Sat Feb  9 2013 dl8fcl@darc.de
- update to version 3.21.68, bug fix
* Fri Feb  1 2013 dl8fcl@darc.de
- update to version 3.21.67, Maintenance release
  RTTY FSK modem improved
* Sun Jan 13 2013 dl8fcl@darc.de
- update to version 3.21.66, Maintenance release
* Tue Jan  1 2013 dl8fcl@darc.de
- update to version 3.21.65
  New high speed and multi carrier modems added
  Separate modem initialization for Olivia
  tone / bandwidth pairs added
* Wed Dec 26 2012 dl8fcl@darc.de
- update to version 3.21.64, Maintenance release
* Wed Dec 12 2012 dl8fcl@darc.de
- update to version 3.21.63, Maintenance release
* Mon Nov 26 2012 dl8fcl@darc.de
- update to version 3.21.62, Maintenance release
* Sun Nov 18 2012 dl8fcl@darc.de
- update to version 3.21.61, Maintenance release
* Mon Nov  5 2012 dl8fcl@darc.de
- update to version 3.21.60, Maintenance release
* Wed Oct 31 2012 dl8fcl@darc.de
- update to version 3.21.59, Maintenance release
* Tue Oct 23 2012 dl8fcl@darc.de
- update to version 3.21.58, Maintenance release
* Sun Sep 23 2012 dl8fcl@darc.de
- update to version 3.21.52, Maintenance release
* Mon Aug  6 2012 dl8fcl@darc.de
- update to version 3.21.50, Maintenance release
* Sun Jul  8 2012 dl8fcl@darc.de
- update to version 3.21.49, Maintenance release
* Sat Jul  7 2012 dl8fcl@darc.de
- update to version 3.21.48, Maintenance release
* Sat Jun 16 2012 dl8fcl@darc.de
- update to version 3.21.43, Maintenance release
* Thu May 31 2012 dl8fcl@darc.de
- update to version 3.21.43
* Tue Mar 27 2012 dl8fcl@darc.de
- update to version 3.21.41, Maintenance release
* Sun Mar  4 2012 dl8fcl@darc.de
- update to version 3.21.40, Maintenance release
* Fri Feb  3 2012 dl8fcl@darc.de
- update to version 3.21.38
* Sun Jan 29 2012 dl8fcl@darc.de
- update to version 3.21.37, Maintenance release
* Tue Jan 24 2012 dl8fcl@darc.de
- update to version 3.21.36, build with fltk-1.1.10 and fltk-1.3.0
* Wed Dec 14 2011 dl8fcl@darc.de
- update to version 3.21.33
* Wed Nov 30 2011 dl8fcl@darc.de
- update to version 3.21.30, log merging bug fixed
* Wed Nov 23 2011 dl8fcl@darc.de
- update to version 3.21.28
* Sun Nov 20 2011 dl8fcl@darc.de
- update to version 3.21.27
* Tue Nov 15 2011 dl8fcl@darc.de
- update to version 3.21.26
* Fri Nov 11 2011 dl8fcl@darc.de
- update to version 3.21.24
* Thu Nov  3 2011 dl8fcl@darc.de
- update to version 3.21.23
* Sat Oct 29 2011 dl8fcl@darc.de
- update to version 3.21.22
* Mon Sep 26 2011 dl8fcl@darc.de
- update to version 3.21.15
* Sun Sep  4 2011 dl8fcl@darc.de
- update to version 3.21.14
* Mon Aug 22 2011 dl8fcl@darc.de
- update to version 3.21.13
* Tue Jun 28 2011 dl8fcl@darc.de
- update to version 3.21.12
* Wed Jun 15 2011 dl8fcl@darc.de
- update to version 3.21.11
* Sat Jun  4 2011 dl8fcl@darc.de
- update to version 3.21.10
* Wed Apr 20 2011 dl8fcl@darc.de
- update to version 3.21.9
* Wed Apr  6 2011 dl8fcl@darc.de
- update to version 3.21.8
* Mon Mar 21 2011 dl8fcl@darc.de
- update to version 3.21.7
* Wed Mar  9 2011 dl8fcl@darc.de
- update to version 3.21.5
* Thu Mar  3 2011 dl8fcl@darc.de
- update to version 3.21.4
* Tue Feb 22 2011 dl8fcl@darc.de
- update to version 3.21.3
* Tue Dec 28 2010 dl8fcl@darc.de
- update to version 3.20.34
* Sat Dec 25 2010 dl8fcl@darc.de
- update to version 3.20.33
* Wed Dec  1 2010 dl8fcl@darc.de
- update to version 3.20.32
* Fri Nov 26 2010 dl8fcl@darc.de
- update to version 3.20.30
* Mon Nov  8 2010 dl8fcl@darc.de
- update to version 3.20.29
* Tue Sep  7 2010 dl8fcl@darc.de
- update to version 3.20.28
* Fri Sep  3 2010 dl8fcl@darc.de
- update to version 3.20.27
* Tue Aug 31 2010 dl8fcl@darc.de
- update to version 3.20.26
* Sat Aug 14 2010 dl8fcl@darc.de
- update to version 3.20.23
* Thu Aug  5 2010 dl8fcl@darc.de
- update to version 3.20.22
* Wed Jul 28 2010 walter.fey@web.de
- update to version 3.20.21
* Sun Jul  4 2010 dl8fcl@darc.de
- update to version 3.20.19
* Tue Jun 29 2010 dl8fcl@darc.de
- update to version 3.20.18
* Tue Jun 22 2010 dl8fcl@darc.de
- update to version 3.20.17
* Wed Jun 16 2010 dl8fcl@darc.de
- update to version 3.20.16
* Sun Jun 13 2010 dl8fcl@darc.de
- update to version 3.20.15
* Mon Jun  7 2010 dl8fcl@darc.de
- update to version 3.20.13
* Wed May 19 2010 dl8fcl@darc.de
- update to version 3.20.12
* Mon May  3 2010 dl8fcl@darc.de
- update to version 3.20.11
* Sun Nov  8 2009 dl8fcl@darc.de
- update to version 3.12.5
* Mon Aug 17 2009 dl8fcl@darc.de
- update to version 3.12.4
* Thu Jul 30 2009 dl8fcl@darc.de
- update to version 3.12.3
* Fri Jul 24 2009 dl8fcl@darc.de
- update to version 3.12
* Wed Jul  8 2009 dl8fcl@darc.de
- update to version 3.11.6
* Sun Jun 14 2009 dl8fcl@darc.de
- update to version 3.11.5
* Sun May 10 2009 dl8fcl@darc.de
- update to version 3.11.4
* Tue May  5 2009 dl8fcl@darc.de
- update to version 3.11.3
* Wed Apr 22 2009 dl8fcl@darc.de
- update to version 3.11.1
* Wed Apr 15 2009 dl8fcl@darc.de
- update to version 3.11
* Sat Jan 17 2009 dl8fcl@darc.de
- update to version 3.10
* Mon Sep 15 2008 dl8fcl@darc.de
- updated to version 3.03
* Tue Aug 26 2008 dl8fcl@darc.de
- updated to version 3.02
* Sun Aug 24 2008 dl8fcl@darc.de
- updated to version 3.01
* Sat Aug 16 2008 dl8fcl@darc.de
- updated to version 3.0
* Wed Jun  4 2008 dg7gt@online.de
- updated to version 2.10.3
* Sun Mar 18 2007 dl9pf@gmx.de
- import into buildservice
